<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ActionPackSystem</name>
    <message>
        <location filename="../actions/actionpacksystem/actionpacksystem.h" line="72"/>
        <source>Actions dealing with the operating system</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::CommandDefinition</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="46"/>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="47"/>
        <source>The command to execute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="50"/>
        <source>Parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="51"/>
        <source>The command&apos;s parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="54"/>
        <source>Working directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="55"/>
        <source>The command&apos;s working directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="56"/>
        <source>Command working directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="60"/>
        <source>Exit code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="61"/>
        <source>The command&apos;s exit code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="64"/>
        <source>Process id</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="65"/>
        <source>The command&apos;s process id</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="68"/>
        <source>Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="69"/>
        <source>The command&apos;s output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="72"/>
        <source>Error output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="73"/>
        <source>The command&apos;s error output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="76"/>
        <source>Exit status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="77"/>
        <source>The command&apos;s exit status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="80"/>
        <source>Failed to start the command</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::CommandInstance</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/commandinstance.h" line="114"/>
        <source>Failed to start the command. %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::DetachedCommandDefinition</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/detachedcommanddefinition.h" line="46"/>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/detachedcommanddefinition.h" line="47"/>
        <source>The command to execute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/detachedcommanddefinition.h" line="50"/>
        <source>Parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/detachedcommanddefinition.h" line="51"/>
        <source>The command&apos;s parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/detachedcommanddefinition.h" line="54"/>
        <source>Working directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/detachedcommanddefinition.h" line="55"/>
        <source>The command&apos;s working directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/detachedcommanddefinition.h" line="56"/>
        <source>Command working directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/detachedcommanddefinition.h" line="60"/>
        <source>Process id</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/detachedcommanddefinition.h" line="61"/>
        <source>The command&apos;s process id</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/detachedcommanddefinition.h" line="64"/>
        <source>Unable to execute the detached command</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::DetachedCommandInstance</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/detachedcommandinstance.h" line="66"/>
        <source>Unable to start the detached command</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::FindImageDefinition</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="57"/>
        <source>Source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="58"/>
        <source>The source of the image to search in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="67"/>
        <source>Window name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="68"/>
        <source>The title of the window to search in, you can use wildcards like * (any number of characters) or ? (one character) here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="71"/>
        <source>Window relative position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="72"/>
        <source>The position is relative to the window
If this parameter is set to false (not checked) then the position is absolute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="81"/>
        <source>Image to search in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="82"/>
        <source>The image to search in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="84"/>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="93"/>
        <source>Choose an image file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="85"/>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="94"/>
        <source>Image files (*.bmp *.gif *.jpg *.jpeg *.mng *.png *.pbm *.pgm *.ppm *.tiff *.xbm *.xpm *.svg)
All files (*.*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="90"/>
        <source>Image to find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="91"/>
        <source>The image to search for</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="97"/>
        <source>If found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="98"/>
        <source>What to do if the image is found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="102"/>
        <source>If not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="103"/>
        <source>What to do if the image is not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="107"/>
        <source>Position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="108"/>
        <source>The name of the variable where to store the coordinates of the center of the found image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="111"/>
        <source>Method</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="112"/>
        <source>The matching method to use</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="117"/>
        <source>Confidence minimum</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="118"/>
        <source>The minimum confidence percentage required to select a possible matching image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="124"/>
        <source>Maximum amount of images to find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="125"/>
        <source>The maximum amount of images to find
Setting this parameter higher will increase the search duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="131"/>
        <source>Downsampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="132"/>
        <source>The downsampling value to use
Downsampling is used to accelerate the search when using large images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="138"/>
        <source>Search expansion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="139"/>
        <source>The number of pixels to shift when searching for another matching image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="145"/>
        <source>Delay between two searches when waiting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="146"/>
        <source>The delay between two searches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="150"/>
        <source> ms</source>
        <comment>milliseconds</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="153"/>
        <source>Confidence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="154"/>
        <source>The name of the variable where to store the confidence value found image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="157"/>
        <source>Error while searching</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::FindImageInstance</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimageinstance.cpp" line="87"/>
        <source>minimum confidence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimageinstance.cpp" line="88"/>
        <source>maximum matches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimageinstance.cpp" line="89"/>
        <source>downsampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimageinstance.cpp" line="90"/>
        <source>search expansion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimageinstance.cpp" line="97"/>
        <source>Invalid image to find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimageinstance.cpp" line="136"/>
        <source>Unable to find any window named %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimageinstance.cpp" line="155"/>
        <source>Invalid image to search in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimageinstance.cpp" line="180"/>
        <source>Error while searching: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::KillProcessDefinition</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/killprocessdefinition.h" line="50"/>
        <source>Process id</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/killprocessdefinition.h" line="51"/>
        <source>The process id of the process to kill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/killprocessdefinition.h" line="54"/>
        <source>Kill mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/killprocessdefinition.h" line="55"/>
        <source>The kill mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/killprocessdefinition.h" line="60"/>
        <source>Timeout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/killprocessdefinition.h" line="61"/>
        <source>The timeout before doing a forceful kill</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::NotifyDefinition</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/notifydefinition.h" line="48"/>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/notifydefinition.h" line="49"/>
        <source>The notification title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/notifydefinition.h" line="52"/>
        <source>Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/notifydefinition.h" line="53"/>
        <source>The notification text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/notifydefinition.h" line="56"/>
        <source>Timeout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/notifydefinition.h" line="57"/>
        <source>The notification timeout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/notifydefinition.h" line="63"/>
        <source>Icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/notifydefinition.h" line="64"/>
        <source>The notification icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/notifydefinition.h" line="67"/>
        <source>Show notification failure</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::NotifyInstance</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/notifyinstance.cpp" line="81"/>
        <source>Unable to show the notification</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::OpenURLDefinition</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/openurldefinition.h" line="44"/>
        <source>URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/openurldefinition.h" line="45"/>
        <source>The url to open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/openurldefinition.h" line="48"/>
        <source>Failed to open URL</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::OpenURLInstance</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/openurlinstance.h" line="59"/>
        <location filename="../actions/actionpacksystem/actions/openurlinstance.h" line="68"/>
        <source>Failed to open URL</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::PixelColorDefinition</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="51"/>
        <source>Pixel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="52"/>
        <source>The pixel position and color to check</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="55"/>
        <source>Comparison</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="56"/>
        <source>The comparison</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="61"/>
        <source>If true</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="62"/>
        <source>What to to if the pixel comparison is true</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="65"/>
        <source>If false</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="66"/>
        <source>What to to if the pixel comparison is false</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="70"/>
        <source>Pixel color variable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="71"/>
        <source>Variable name where to store the pixel color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="74"/>
        <source>Red tolerance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="75"/>
        <source>The tolerance percentage for the red color component</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="81"/>
        <source>Green tolerance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="82"/>
        <source>The tolerance percentage for the green color component</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="88"/>
        <source>Blue tolerance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="89"/>
        <source>The tolerance percentage for the blue color component</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="95"/>
        <source>Offset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="96"/>
        <source>The offset to apply to the pixel position</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::PlaySoundDefinition</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="48"/>
        <source>Sound file/URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="49"/>
        <source>The sound file or URL to play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="51"/>
        <source>Choose the sound file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="52"/>
        <source>All files (*.*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="55"/>
        <source>URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="56"/>
        <source>Is the sound resource an URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="60"/>
        <source>Volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="61"/>
        <source>The volume to play at</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="64"/>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="82"/>
        <source>%</source>
        <comment>percent</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="68"/>
        <source>Wait until played</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="69"/>
        <source>Should the action end only when the sound has finished playing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="73"/>
        <source>Looping</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="74"/>
        <source>Should the sound loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="78"/>
        <source>Playback rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="79"/>
        <source>The playback rate</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::PlaySoundInstance</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsoundinstance.cpp" line="67"/>
        <source>Unable to load file %1: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsoundinstance.cpp" line="79"/>
        <source>Unable to play file %1: %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::SystemDefinition</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/systemdefinition.h" line="49"/>
        <source>Operation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systemdefinition.h" line="50"/>
        <source>The operation to execute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systemdefinition.h" line="64"/>
        <source>Force</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systemdefinition.h" line="65"/>
        <source>Should the operation be forced</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systemdefinition.h" line="71"/>
        <source>Not available</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::SystemInstance</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/systeminstance.cpp" line="54"/>
        <source>Logout is not available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systeminstance.cpp" line="61"/>
        <source>Restart is not available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systeminstance.cpp" line="68"/>
        <source>Shutdown is not available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systeminstance.cpp" line="75"/>
        <source>Suspend is not available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systeminstance.cpp" line="82"/>
        <source>Hibernate is not available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systeminstance.cpp" line="89"/>
        <source>Lock is not available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systeminstance.cpp" line="96"/>
        <source>Start screen saver is not available</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Code::MediaPlaylist</name>
    <message>
        <location filename="../actions/actionpacksystem/code/mediaplaylist.cpp" line="161"/>
        <location filename="../actions/actionpacksystem/code/mediaplaylist.cpp" line="172"/>
        <source>Add media failed : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/mediaplaylist.cpp" line="183"/>
        <location filename="../actions/actionpacksystem/code/mediaplaylist.cpp" line="194"/>
        <source>Insert media failed : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/mediaplaylist.cpp" line="205"/>
        <source>Clear failed : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/mediaplaylist.cpp" line="251"/>
        <source>Remove media failed : %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Code::Notify</name>
    <message>
        <location filename="../actions/actionpacksystem/code/notify.cpp" line="110"/>
        <source>Unable to show the notification</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Code::Process</name>
    <message>
        <location filename="../actions/actionpacksystem/code/process.cpp" line="90"/>
        <location filename="../actions/actionpacksystem/code/process.cpp" line="161"/>
        <source>Invalid filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/process.cpp" line="112"/>
        <source>Unable to start the process</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/process.cpp" line="251"/>
        <location filename="../actions/actionpacksystem/code/process.cpp" line="256"/>
        <location filename="../actions/actionpacksystem/code/process.cpp" line="265"/>
        <source>Write failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/process.cpp" line="351"/>
        <source>Invalid process</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/process.cpp" line="363"/>
        <source>Wait for finished failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/process.cpp" line="371"/>
        <source>Wait for started failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/process.cpp" line="379"/>
        <source>Waiting for bytes written failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/process.cpp" line="387"/>
        <source>Waiting for ready read failed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Code::System</name>
    <message>
        <location filename="../actions/actionpacksystem/code/system.cpp" line="103"/>
        <source>Cannot open the url</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/system.cpp" line="337"/>
        <source>Logout failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/system.cpp" line="345"/>
        <source>Restart failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/system.cpp" line="353"/>
        <source>Shutdown failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/system.cpp" line="361"/>
        <source>Suspend failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/system.cpp" line="369"/>
        <source>Hibernate failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/system.cpp" line="377"/>
        <source>Lock screen failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/system.cpp" line="385"/>
        <source>Start screen saver failed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FindImageInstance::sources</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimageinstance.cpp" line="35"/>
        <source>Screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimageinstance.cpp" line="36"/>
        <source>Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimageinstance.cpp" line="37"/>
        <source>Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimageinstance.cpp" line="41"/>
        <source>Correlation Coefficient</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimageinstance.cpp" line="42"/>
        <source>Cross Correlation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimageinstance.cpp" line="43"/>
        <source>Squared Difference</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KillProcessInstance::killModes</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/killprocessinstance.cpp" line="28"/>
        <source>Graceful</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/killprocessinstance.cpp" line="29"/>
        <source>Forceful</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/killprocessinstance.cpp" line="30"/>
        <source>Graceful then forceful</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PixelColorInstance::comparisons</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolorinstance.cpp" line="28"/>
        <source>Equal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolorinstance.cpp" line="29"/>
        <source>Darker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolorinstance.cpp" line="30"/>
        <source>Lighter</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="83"/>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="86"/>
        <source>Executes a command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/detachedcommanddefinition.h" line="67"/>
        <source>Detached command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/detachedcommanddefinition.h" line="70"/>
        <source>Executes a detached command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="160"/>
        <source>Find image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="163"/>
        <source>Finds an image on the screen, on a window or on another image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/killprocessdefinition.h" line="68"/>
        <source>Kill process</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/killprocessdefinition.h" line="71"/>
        <source>Kills a process</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/notifydefinition.h" line="70"/>
        <source>Notify</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/notifydefinition.h" line="73"/>
        <source>Shows a message using the notify system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/openurldefinition.h" line="51"/>
        <source>Open URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/openurldefinition.h" line="54"/>
        <source>Opens an URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="100"/>
        <source>Pixel color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="103"/>
        <source>Check a pixel color on the screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="87"/>
        <source>Play sound</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="90"/>
        <source>Plays a sound</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systemdefinition.h" line="74"/>
        <source>System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systemdefinition.h" line="77"/>
        <source>Restart, stop the computer or logout the current user</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SystemInstance::operations</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/systeminstance.cpp" line="29"/>
        <source>Logout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systeminstance.cpp" line="30"/>
        <source>Reboot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systeminstance.cpp" line="31"/>
        <source>Shutdown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systeminstance.cpp" line="32"/>
        <source>Suspend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systeminstance.cpp" line="33"/>
        <source>Hibernate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systeminstance.cpp" line="34"/>
        <source>Lock screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systeminstance.cpp" line="35"/>
        <source>Start screen saver</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
